<template>
  <ProDialog
    :title="innerForm.title"
    v-model="innerVisible"
    @close="onDialogClose"
    destroy-on-close
  >
    <ProForm :rules="rules" :model="innerForm" ref="dialogForm" label-width="120px">
      <ProFormItemV2
        label="广告页面:"
        prop="pageType"
        :check-rules="[{ message: '请选择广告页面' }]"
      >
        <ProFormSelect
          placeholder="请选择广告页面"
          :value-enum="FlexWorkerEleSignEnumText"
          clearable
          v-model="innerForm.pageType"
        ></ProFormSelect>
      </ProFormItemV2>
      <ProFormItemV2
        label="广告名称:"
        prop="advertiseName"
        :check-rules="[{ message: '请输入广告名称' }, { max: 20, message: '不能超过20个字符' }]"
      >
        <ProFormText
          placeholder="请输入广告名称"
          v-model.trim="innerForm.advertiseName"
          :maxlength="20"
        ></ProFormText>
      </ProFormItemV2>
      <ProFormItemV2
        label="广告产品链接:"
        prop="advertiseLink"
        :check-rules="[
          { type: 'urlWithParams', message: '请输入广告产品链接' },
          { message: '请输入正确的广告产品链接' },
        ]"
      >
        <ProFormText
          placeholder="请输入广告产品链接"
          v-model.trim="innerForm.advertiseLink"
          :maxlength="150"
        ></ProFormText>
      </ProFormItemV2>
      <ProFormItemV2
        label="广告图片:"
        prop="imgInfo"
        :check-rules="[{ type: 'array', message: '请选择广告图片' }]"
      >
        <ProFormImageUpload
          :fileDirectory="OssAdvertise"
          v-model:file-url="innerForm.imgInfo"
          :limitFileCount="1"
        ></ProFormImageUpload>
      </ProFormItemV2>
      <ProFormItemV2
        label="广告日期:"
        prop="date"
        :check-rules="[{ type: 'array', message: '请选择广告日期' }]"
      >
        <ProFormDatePicker
          v-model="innerForm.date"
          type="daterange"
          range-separator="~"
          start-placeholder="广告起始日期"
          end-placeholder="广告到期日期"
          clearable
        ></ProFormDatePicker>
      </ProFormItemV2>
      <ProFormItemV2
        label="广告位排序:"
        prop="sort"
        required
        :check-rules="[{ message: '请输入排序' }]"
      >
        <ProFormInputNumber
          v-model="innerForm.sort"
          :controls="false"
          :min="0"
          :max="99"
        ></ProFormInputNumber>
      </ProFormItemV2>
    </ProForm>
    <template #footer>
      <span class="dialog-footer">
        <el-button @click="emit('onCancel')">取 消</el-button>
        <el-button type="primary" @click="handleConfirm">确 定</el-button>
      </span>
    </template>
  </ProDialog>
</template>

<script setup lang="ts">
import { FormRules, FormInstance } from 'element-plus';
import {
  ProDialog,
  ProForm,
  ProFormItemV2,
  UploadUserFile,
  ProFormText,
  ProFormDatePicker,
  ProFormInputNumber,
  ProFormSelect,
  ProFormImageUpload,
} from '@bole-core/components';
import { ModelValueType } from 'element-plus';
import { OssAdvertise, FlexWorkerEleSignEnumText } from '@/constants';
import { BoleRegExp } from '@bole-core/core';

defineOptions({
  name: 'AddOrEditAdvertisementDialog',
});

type Props = {
  modelValue: boolean;
  form?: {
    title?: string;
    id: string;
    pageType: number;
    advertiseName: string;
    advertiseLink: string;
    imgInfo: UploadUserFile[];
    date: ModelValueType;
    sort: number;
  };
};

const props = withDefaults(defineProps<Props>(), {
  modelValue: false,
});

const emit = defineEmits<{
  (e: 'update:modelValue', value: boolean): void;
  (e: 'update:form', value: Props['form']): void;
  (e: 'onConfirm'): void;
  (e: 'onCancel'): void;
}>();

const dialogForm = ref<FormInstance>();

const innerVisible = computed({
  get() {
    return props.modelValue;
  },
  set(val) {
    emit('update:modelValue', val);
  },
});

const innerForm = computed({
  get() {
    return props.form;
  },
  set(val) {
    emit('update:form', val);
  },
});

const rules = reactive<FormRules>({
  contacterPhone: [
    { message: '请输入正确的联系电话', trigger: 'blur', pattern: BoleRegExp.RegTelNumber },
  ],
});

function onDialogClose() {
  if (!dialogForm.value) return;
  dialogForm.value.resetFields();
}

function handleConfirm() {
  if (!dialogForm.value) return;
  dialogForm.value.validate((valid) => {
    if (valid) {
      emit('onConfirm');
    } else {
      return;
    }
  });
}
</script>
